Learn R Programming

BivGeo (version 2.0.1)

corbivgeo: Correlation Coefficient for the Basu-Dhar Bivariate Geometric Distribution

Description

This function computes the correlation coefficient analogous of the Pearson correlation coefficient for the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

corbivgeo(theta)

Arguments

theta

vector (of length 3) containing values of the parameters \(\theta_1, \theta_2\) and \(\theta_{3}\) of the Basu-Dhar bivariate Geometric distribution. For real data applications, use the maximum likelihood estimates or Bayesian estimates to get the correlation coefficient.

Value

corbivgeo computes the correlation coefficient analogous to the Pearson correlation coefficient for the Basu-Dhar bivariate geometric distribution for arbitrary parameter values.

Invalid arguments will return an error message.

Details

The correlation coefficient between X and Y, assuming the Basu-Dhar bivariate geometric distribution, is given by,

$$\rho = \frac{(1 - \theta_{3})(\theta_1 \theta_2)^{1/2}}{1 - \theta_1 \theta_2 \theta_{3}}$$

Note that the correlation coefficient is always positive which implies that the Basu-Dhar bivariate geometric distribution is useful for bivariate lifetimes with positive correlation.

References

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu<U+2013>Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

de Oliveira, R. P., Achcar, J. A., Peralta, D., & Mazucheli, J. (2018). Discrete and continuous bivariate lifetime models in presence of cure rate: a comparative study under Bayesian approach. Journal of Applied Statistics, 1-19.

Examples

Run this code
# NOT RUN {
corbivgeo(theta = c(0.5, 0.5, 0.7))
# [1] 0.1818182
corbivgeo(theta = c(0.2, 0.5, 0.7))
# [1] 0.102009
corbivgeo(theta = c(0.8, 0.9, 0.1))
# [1] 0.822926
corbivgeo(theta = c(0.9, 0.9, 0.9))
# [1] 0.3321033

# }

Run the code above in your browser using DataLab