Learn R Programming

BivGeo (version 2.0.1)

rbivgeo: Generates Random Deviates from the Basu-Dhar Bivariate Geometric Distribution

Description

This function generates random values from the Basu-Dhar bivariate geometric distribution assuming arbitrary parameter values.

Usage

rbivgeo1(n, theta)
rbivgeo2(n, theta)

Arguments

n

number of observations. If length(n) \(> 1\), the length is taken to be the number required.

theta

vector (of length 3) containing values of the parameters \(\theta_1, \theta_2\) and \(\theta_{3}\) of the Basu-Dhar bivariate Geometric distribution. The parameters are restricted to \(0 < \theta_i < 1, i = 1,2\) and \(0 < \theta_{3} \le 1\).

Value

rbivgeo1 and rbivgeo2 generate random deviates from the Bash-Dhar bivariate geometric distribution. The length of the result is determined by n, and is the maximum of the lengths of the numerical arguments for the other functions.

Invalid arguments will return an error message.

Details

The conditional distribution of X given Y is given by:

If X < Y, then $$P(X = x | Y = y) = \theta_1^{x - 1}(1 - \theta_1)$$ If X = Y, then $$P(X = x | Y = y) = \frac{\theta_1^{x - 1}(1 - \theta_1 \theta_{3} - \theta_2 \theta_{3} + \theta_1 \theta_2 \theta_{3})}{1 - \theta_2 \theta_{3}} $$ If X > Y, then $$P(X = x | Y = y) = \frac{\theta_1^{x - 1} \theta_{3}^{x - y}(1 - \theta_{1} \theta_{3}) (1 - \theta_2)}{1 - \theta_2 \theta_{3}}$$

References

Marshall, A. W., & Olkin, I. (1967). A multivariate exponential distribution. Journal of the American Statistical Association, 62, 317, 30-44.

Basu, A. P., & Dhar, S. K. (1995). Bivariate geometric distribution. Journal of Applied Statistical Science, 2, 1, 33-44.

Li, J., & Dhar, S. K. (2013). Modeling with bivariate geometric distributions. Communications in Statistics-Theory and Methods, 42, 2, 252-266.

Achcar, J. A., Davarzani, N., & Souza, R. M. (2016). Basu<U+2013>Dhar bivariate geometric distribution in the presence of covariates and censored data: a Bayesian approach. Journal of Applied Statistics, 43, 9, 1636-1648.

de Oliveira, R. P., & Achcar, J. A. (2018). Basu-Dhar's bivariate geometric distribution in presence of censored data and covariates: some computational aspects. Electronic Journal of Applied Statistical Analysis, 11, 1, 108-136.

See Also

Geometric for the univariate geometric distribution.

Examples

Run this code
# NOT RUN {
rbivgeo1(n = 10, theta = c(0.5, 0.5, 0.7))
#       [,1] [,2]
#  [1,]    2    1
#  [2,]    3    1
#  [3,]    1    1
#  [4,]    1    1
#  [5,]    2    2
#  [6,]    1    3
#  [7,]    2    2
#  [8,]    1    1
#  [9,]    1    1
# [10,]    2    2

rbivgeo2(n = 10, theta = c(0.5, 0.5, 0.7))
#       [,1] [,2]
#  [1,]    1    1
#  [2,]    2    1
#  [3,]    2    1
#  [4,]    4    1
#  [5,]    1    1
#  [6,]    2    2
#  [7,]    3    2
#  [8,]    3    1
#  [9,]    3    2
# [10,]    1    1

# }

Run the code above in your browser using DataLab